#!/bin/bash

# called by dracut
check() {
    [[ $mount_needs ]] && return 1

    if ! dracut_module_included "systemd-initrd"; then
        derror "dracut-systemd needs systemd-initrd in the initramfs"
        return 1
    fi

    return 0
}

# called by dracut
depends() {
    echo "systemd-initrd"
    return 0
}

installkernel() {
    return 0
}

# called by dracut
install() {
    local _mods

    # PowerFailSafeguard
    inst_script "$moddir/restore-to.sh" /bin/restore-to

    inst "/usr/bin/rsync" "/usr/bin/rsync"
    inst "/usr/bin/df" "/usr/bin/df"
    inst "/usr/sbin/fuser" "/usr/sbin/fuser"
    inst "/usr/bin/crontab" "/usr/bin/crontab"
    inst "/usr/bin/touch" "/usr/bin/touch"
    inst "/usr/bin/lsblk" "/usr/bin/lsblk"
    inst "/usr/bin/chmod" "/usr/bin/chmod"
    inst "/usr/bin/wc" "/usr/bin/wc"
    inst "/usr/bin/rmdir" "/usr/bin/rmdir"
    inst "/usr/bin/timeshift" "/usr/bin/timeshift"
    inst "/usr/sbin/vgdisplay" "/usr/sbin/vgdisplay"
    inst "/usr/sbin/vgchange" "/usr/sbin/vgchange"
    inst "/usr/bin/ldd" "/usr/bin/ldd"
    inst "/usr/bin/cut" "/usr/bin/cut"
    inst "/usr/bin/which" "/usr/bin/which"
    inst "/usr/sbin/plymouth-set-default-theme" "/usr/sbin/plymouth-set-default-theme"
    inst "/usr/lib64/plymouth/script.so" "/usr/lib64/plymouth/script.so"
    inst "/usr/bin/awk" "/usr/bin/awk"
    inst "/usr/bin/basename" "/usr/bin/basename"
    inst "/usr/bin/id" "/usr/bin/id"
    inst "/usr/bin/sync" "/usr/bin/sync"
    inst "/usr/bin/tty" "/usr/bin/tty"
    inst "/usr/bin/find" "/usr/bin/find"
    inst "/usr/bin/head" "/usr/bin/head"

    if [[ -d /usr/share/plymouth/themes/restore ]]; then
        mkdir -m 0755 -p "/usr/share/plymouth/themes/restore"
        for x in "/usr/share/plymouth/themes/restore"/* ; do
            [[ -f "$x" ]] || break
            inst_multiple $x
        done
    fi

    mkdir -p "${initdir}/$systemdsystemunitdir/initrd.target.wants"
    for i in \
        restore-to.service \
        ; do
        inst_simple "$moddir/${i}" "$systemdsystemunitdir/${i}"
        ln_r "$systemdsystemunitdir/${i}" "$systemdsystemunitdir/initrd.target.wants/${i}"
    done

}
