#!/bin/sh

echo "********** Tsrestore Begin! ***********"

rootmnt="/sysroot"
flagpath="${rootmnt}/.tsrestore"
base_backup_comment="backup_of_base_os"

function do_restore
{
    restore_type=$1
    restore_to=
    
    # activate lvm
    declare arr=($(vgdisplay | grep -i "vg name" | awk '{print $3}'))
    for vgname in ${arr[@]}; do
        if [[ -z $vgname ]];then
            echo "get vg name failed"
            return
        fi

        vgchange -ay $vgname
        if [[ $? -ne 0 ]];then
            echo "vgchange -ay $vgname failed"
        fi
    done

    cp -aR ${rootmnt}/etc/timeshift /etc/

    if [[ $restore_type == "to" ]];then
        restore_to=$(cat $flagpath)
    elif [[ $restore_type == "base" ]];then
        restore_to=$(timeshift --list | grep ">" | grep $base_backup_comment | awk '{print $3}')
    else
        echo "do_restore invalid param: $restore_type"
        return
    fi
        
    if [[ -z $restore_to ]];then
        echo "backup to restore invalid: $restore_to"
        return
    fi

    backups=$(timeshift --list | grep ">" | awk '{print $3}')
    for i in $backups;do
        if [[ $restore_to == $i ]];then
            backupexist=1
	    break
	fi
    done

    if [[ -z $backupexist ]];then
        echo "backup to restore donot exist: $restore_to"
	    return
    fi 

    cmd="timeshift --restore --skip-grub --yes --snapshot $restore_to"
    echo "exec $cmd"

    /usr/bin/plymouth quit
    /usr/sbin/plymouth-set-default-theme restore

    /usr/sbin/plymouthd --mode=boot --attach-to-session
    /usr/bin/plymouth show-splash

    /usr/bin/plymouth message --text=50

    mount -o remount,rw $rootmnt
    if [[ $? -ne 0 ]];then
        echo "remount /sysroot rw failed"
        return
    fi

    $cmd
    ret=$?

    if [[ $ret -eq 0 ]];then
        /usr/bin/plymouth message --text=r_success
        echo "restore to $restore_to succeed"
    else
        /usr/bin/plymouth message --text=r_failed
        echo "restore to $restore_to failed"
    fi   

    sleep 2
    /usr/bin/plymouth quit
    /usr/sbin/plymouth-set-default-theme kiran

    if [[ $restore_type == "to"  ]];then
        rm -f $flagpath 
    fi
        
    touch ${rootmnt}/.autorelabel.br

    sync && reboot -f
}

function main
{
    cat /proc/cmdline | grep disablerestore >/dev/null
    if [[ $? -eq 0 ]];then
        echo "find disablets in cmdline,exit"
        return
    fi

    cat /proc/cmdline | grep kyrestore >/dev/null
    if [[ $? -eq 0 ]];then
        do_restore base
    fi

    if [[ -e $flagpath ]];then
        do_restore to
    fi
}

main

echo "********** Tsrestore Finished! ***********"


